ImageSaver

Struct ImageSaver 

pub struct ImageSaver;
AssetSaver for images that can be saved by the image crate.

Unlike CompressedImageSaver, this does not attempt to do any “texture optimization”, like compression (though some file formats intrinsically perform some compression, e.g., JPEG).

Some file formats do not support all texture formats (e.g., PNG does not support TextureFormat::Rg8Unorm). In some cases, ImageSaver will convert the image to allow writing as the requested file format.