pub trait TextureSrgbViewFormats {
// Required method
fn srgb_view_formats(&self) -> &'static [TextureFormat];
}Expand description
Trait used to provide texture srgb view formats with static lifetime for TextureDescriptor.view_formats.
Required Methods
Sourcefn srgb_view_formats(&self) -> &'static [TextureFormat]
fn srgb_view_formats(&self) -> &'static [TextureFormat]
Returns the srgb view formats for a type.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl TextureSrgbViewFormats for TextureFormat
impl TextureSrgbViewFormats for TextureFormat
Sourcefn srgb_view_formats(&self) -> &'static [TextureFormat]
fn srgb_view_formats(&self) -> &'static [TextureFormat]
Returns the srgb view formats if the format has an srgb variant, otherwise returns an empty slice.
The return result covers all the results of TextureFormat::add_srgb_suffix.